@@ -76,65 +76,6 @@
 
 namespace core {
 
-void
-Manager::handshake_log(const sockaddr* sa, int msg, int err, const torrent::HashString* hash) {
-  if (!rpc::call_command_value("log.handshake"))
-    return;
-  
-  std::string peer;
-  std::string download;
-
-  const rak::socket_address* socketAddress = rak::socket_address::cast_from(sa);
-
-  if (socketAddress->is_valid()) {
-    char port[6];
-    snprintf(port, sizeof(port), "%d", socketAddress->port());
-    peer = socketAddress->address_str() + ":" + port;
-  } else {
-    peer = "(unknown)";
-  }
-
-//   torrent::Download d = torrent::download_find(hash);
-
-//   if (d.is_valid())
-//     download = ": " + d.name();
-//   else
-    download = "";
-
-  switch (msg) {
-  case torrent::ConnectionManager::handshake_incoming:
-    push_log_complete("Incoming connection from " + peer + download);
-    break;
-  case torrent::ConnectionManager::handshake_outgoing:
-    push_log_complete("Outgoing connection to " + peer + download);
-    break;
-  case torrent::ConnectionManager::handshake_outgoing_encrypted:
-    push_log_complete("Outgoing encrypted connection to " + peer + download);
-    break;
-  case torrent::ConnectionManager::handshake_outgoing_proxy:
-    push_log_complete("Outgoing proxy connection to " + peer + download);
-    break;
-  case torrent::ConnectionManager::handshake_success:
-    push_log_complete("Successful handshake: " + peer + download);
-    break;
-  case torrent::ConnectionManager::handshake_dropped:
-    push_log_complete("Dropped handshake: " + peer + " - " + torrent::strerror(err) + download);
-    break;
-  case torrent::ConnectionManager::handshake_failed:
-    push_log_complete("Handshake failed: " + peer + " - " + torrent::strerror(err) + download);
-    break;
-  case torrent::ConnectionManager::handshake_retry_plaintext:
-    push_log_complete("Trying again without encryption: " + peer + download);
-    break;
-  case torrent::ConnectionManager::handshake_retry_encrypted:
-    push_log_complete("Trying again encrypted: " + peer + download);
-    break;
-  default:
-    push_log_complete("Unknown handshake message for " + peer + download);
-    break;
-  }
-}
-
 void
 Manager::push_log(const char* msg) {
   m_log_important->lock_and_push_log(msg, strlen(msg), 0);
@@ -194,7 +135,7 @@ Manager::get_throttle(const std::string& name) {
 void
 Manager::set_address_throttle(uint32_t begin, uint32_t end, torrent::ThrottlePair throttles) {
   m_addressThrottles.set_merge(begin, end, throttles);
-  torrent::connection_manager()->set_address_throttle(sigc::mem_fun(control->core(), &core::Manager::get_address_throttle));
+  torrent::connection_manager()->address_throttle() = tr1::bind(&core::Manager::get_address_throttle, control->core(), tr1::placeholders::_1);
 }
 
 torrent::ThrottlePair
@@ -209,8 +150,6 @@ Manager::initialize_second() {
   m_httpQueue->slot_factory(sigc::mem_fun(m_httpStack, &CurlStack::new_object));
 
   CurlStack::global_init();
-
-  torrent::connection_manager()->set_signal_handshake_log(sigc::mem_fun(this, &Manager::handshake_log));
 }
 
 void
@@ -246,7 +185,7 @@ Manager::listen_open() {
     return;
 
   int portFirst, portLast;
-  torrent::Object portRange = rpc::call_command_void("network.port_range");
+  torrent::Object portRange = rpc::call_command("network.port_range");
 
   if (portRange.is_string()) {
     if (std::sscanf(portRange.as_string().c_str(), "%i-%i", &portFirst, &portLast) != 2)
