@@ -40,6 +40,7 @@
 
 #include <cstdlib>
 #include <iostream>
+#include <sstream>
 #include <string>
 #include <inttypes.h>
 #include <sigc++/adaptors/bind.h>
@@ -238,15 +239,6 @@ main(int argc, char** argv) {
 
     rpc::parse_command_multiple
       (rpc::make_target(),
-//        "method.insert = test.value,value\n"
-//        "method.insert = test.value2,value,6\n"
-
-//        "method.insert = test.string,string,6\n"
-//        "method.insert = test.bool,bool,true\n"
-
-       // "method.insert.simple = test.method.simple,((print,simple_test_,$argument.0=))\n"
-       // "method.insert.simple = test.method.double,((print,simple_test_,$argument.0=)),\"print=simple_test_,$argument.1=\"\n"
-
        "method.insert = event.download.inserted,multi|rlookup|static\n"
        "method.insert = event.download.inserted_new,multi|rlookup|static\n"
        "method.insert = event.download.inserted_session,multi|rlookup|static\n"
@@ -265,8 +257,8 @@ main(int argc, char** argv) {
 
        "method.set_key = event.download.inserted,         1_connect_logs, ((d.initialize_logs))\n"
        "method.set_key = event.download.inserted,         1_send_scrape, ((d.tracker.send_scrape,30))\n"
-       "method.set_key = event.download.inserted_new,     1_prepare, \"branch=d.state=,view.set_visible=started,view.set_visible=stopped ;d.save_full_session=\"\n"
-       "method.set_key = event.download.inserted_session, 1_prepare, \"branch=d.state=,view.set_visible=started,view.set_visible=stopped\"\n"
+       "method.set_key = event.download.inserted_new,     1_prepare, {(branch,((d.state)),((view.set_visible,started)),((view.set_visible,stopped)) ),(d.save_full_session)}\n"
+       "method.set_key = event.download.inserted_session, 1_prepare, {(branch,((d.state)),((view.set_visible,started)),((view.set_visible,stopped)) )}\n"
 
        "method.set_key = event.download.inserted, 1_prioritize_toc, \"branch=file.prioritize_toc=,{\\\"f.multicall=(file.prioritize_toc.first),f.prioritize_first.enable=\\\",\\\"f.multicall=(file.prioritize_toc.last),f.prioritize_last.enable=\\\",d.update_priorities=}\"\n"
 
@@ -292,7 +284,7 @@ main(int argc, char** argv) {
 
        "group.insert = seeding,seeding\n"
 
-       "session.name.set = \"$cat=$system.hostname=,:,$system.pid=\"\n"
+       "session.name.set = (cat,(system.hostname),:,(system.pid))\n"
 
        // Currently not doing any sorting on main.
        "view.add = main\n"
@@ -307,46 +299,36 @@ main(int argc, char** argv) {
 
        "view.add = started\n"
        "view.filter = started,((false))\n"
-       "view.event_added   = started,\"view.set_not_visible=stopped ;d.state.set=1 ;scheduler.simple.added=\"\n"
-       "view.event_removed = started,\"view.set_visible=stopped ;scheduler.simple.removed=\"\n"
+       "view.event_added   = started,{(view.set_not_visible,stopped),(d.state.set,1),(scheduler.simple.added)}\n"
+       "view.event_removed = started,{(view.set_visible,stopped),(scheduler.simple.removed)}\n"
 
        "view.add = stopped\n"
        "view.filter = stopped,((false))\n"
-       "view.event_added   = stopped,\"d.state.set=0 ;view.set_not_visible=started\"\n"
-       "view.event_removed = stopped,view.set_visible=started\n"
+       "view.event_added   = stopped,{(d.state.set,0),(view.set_not_visible,started)}\n"
+       "view.event_removed = stopped,((view.set_visible,started))\n"
 
        "view.add = complete\n"
        "view.filter = complete,((d.complete))\n"
        "view.filter_on    = complete,event.download.hash_done,event.download.hash_failed,event.download.hash_final_failed,event.download.finished\n"
-       // "view.sort_new     = complete,((less,((d.state_changed))))\n"
-       // "view.sort_current = complete,((less,((d.state_changed))))\n"
 
        "view.add = incomplete\n"
        "view.filter = incomplete,((not,((d.complete))))\n"
        "view.filter_on    = incomplete,event.download.hash_done,event.download.hash_failed,"
                                       "event.download.hash_final_failed,event.download.finished\n"
-       // "view.sort_new     = incomplete,((less,((d.state_changed))))\n"
-       // "view.sort_current = incomplete,((less,((d.state_changed))))\n"
 
        // The hashing view does not include stopped torrents.
        "view.add = hashing\n"
        "view.filter = hashing,((d.hashing))\n"
        "view.filter_on = hashing,event.download.hash_queued,event.download.hash_removed,"
                                 "event.download.hash_done,event.download.hash_failed,event.download.hash_final_failed,event.download.finished\n"
-//        "view.sort_new     = hashing,less=d.state_changed=\n"
-//        "view.sort_current = hashing,less=d.state_changed=\n"
 
        "view.add    = seeding\n"
        "view.filter = seeding,((and,((d.state)),((d.complete))))\n"
-       "view.filter_on    = seeding,event.download.resumed,event.download.paused,event.download.finished\n"
-       // "view.sort_new     = seeding,((less,((d.state_changed))))\n"
-       // "view.sort_current = seeding,((less,((d.state_changed))))\n"
+       "view.filter_on = seeding,event.download.resumed,event.download.paused,event.download.finished\n"
 
        "view.add    = leeching\n"
        "view.filter = leeching,((and,((d.state)),((not,((d.complete))))))\n"
-       "view.filter_on    = leeching,event.download.resumed,event.download.paused,event.download.finished\n"
-       // "view.sort_new     = leeching,((less,((d.state_changed))))\n"
-       // "view.sort_current = leeching,((less,((d.state_changed))))\n"
+       "view.filter_on = leeching,event.download.resumed,event.download.paused,event.download.finished\n"
 
        "schedule2 = view.main,10,10,((view.sort,main,20))\n"
        "schedule2 = view.name,10,10,((view.sort,name,20))\n"
@@ -447,9 +429,6 @@ main(int argc, char** argv) {
 
       CMD2_REDIRECT        ("session_save", "session.save");
 
-      CMD2_REDIRECT        ("get_handshake_log", "log.handshake");
-      CMD2_REDIRECT_GENERIC("set_handshake_log", "log.handshake.set");
-
       CMD2_REDIRECT        ("get_name", "session.name");
       CMD2_REDIRECT_GENERIC("set_name", "session.name.set");
 
@@ -874,10 +853,20 @@ main(int argc, char** argv) {
     control->core()->download_list()->session_save();
     control->cleanup();
 
+  } catch (torrent::internal_error& e) {
+    control->cleanup_exception();
+
+    std::cout << "Caught internal_error: " << e.what() << std::endl
+              << e.backtrace();
+    lt_log_print_dump(torrent::LOG_CRITICAL, e.backtrace().c_str(), e.backtrace().size(),
+                      "Caught internal_error: '%s'.", e.what());
+    return -1;
+
   } catch (std::exception& e) {
     control->cleanup_exception();
 
     std::cout << "rtorrent: " << e.what() << std::endl;
+    lt_log_print(torrent::LOG_CRITICAL, "Caught exception: '%s'.", e.what());
     return -1;
   }
 
@@ -897,9 +886,8 @@ handle_sigbus(int signum, siginfo_t* sa, void* ptr) {
   SignalHandler::set_default(signum);
   display::Canvas::cleanup();
 
-  // Use printf here instead...
-
-  printf("Caught SIGBUS, dumping stack:\n");
+  std::stringstream output;
+  output << "Caught SIGBUS, dumping stack:" << std::endl;
 
 #ifdef USE_EXECINFO
   void* stackPtrs[20];
@@ -909,13 +897,12 @@ handle_sigbus(int signum, siginfo_t* sa, void* ptr) {
   char** stackStrings = backtrace_symbols(stackPtrs, stackSize);
 
   for (int i = 0; i < stackSize; ++i)
-    printf("%i %s\n", i, stackStrings[i]);
+    output << stackStrings[i] << std::endl;
 
 #else
-  printf("Stack dump not enabled.\n");
+  output << "Stack dump not enabled." << std::endl;
 #endif
-  
-  printf("\nError: %s\n", rak::error_number(sa->si_errno).c_str());
+  output << std::endl << "Error: " << rak::error_number(sa->si_errno).c_str() << std::endl;
 
   const char* signal_reason;
 
@@ -932,23 +919,31 @@ handle_sigbus(int signum, siginfo_t* sa, void* ptr) {
     break;
   };
 
-  printf("Signal code '%i': %s\n", sa->si_code, signal_reason);
-  printf("Fault address: %p.\n\n", sa->si_addr);
+  output << "Signal code '" << sa->si_code << "': " << signal_reason << std::endl;
+  output << "Fault address: " << sa->si_addr << std::endl;
 
   // New code for finding the location of the SIGBUS signal, and using
   // that to figure out how to recover.
   torrent::chunk_info_result result = torrent::chunk_list_address_info(sa->si_addr);
 
   if (!result.download.is_valid()) {
-    printf("The fault address is not part of any chunk.\n");
-    std::abort();
+    output << "The fault address is not part of any chunk." << std::endl;
+    goto handle_sigbus_exit;
   }
 
-  printf("Torrent name: '%s'.\n", result.download.info()->name().c_str());
-  printf("File name:    '%s'.\n", result.file_path);
-  printf("File offset:  %" PRIu64 ".\n", result.file_offset);
-  printf("Chunk index:  %u.\n", result.chunk_index);
-  printf("Chunk offset: %u.\n", result.chunk_offset);
+  output << "Torrent name: " << result.download.info()->name().c_str() << std::endl;
+  output << "File name:    " << result.file_path << std::endl;
+  output << "File offset:  " << result.file_offset << std::endl;
+  output << "Chunk index:  " << result.chunk_index << std::endl;
+  output << "Chunk offset: " << result.chunk_offset << std::endl;
+
+handle_sigbus_exit:
+  std::cout << output.rdbuf();
+
+  if (lt_log_is_valid(torrent::LOG_CRITICAL)) {
+    std::string dump = output.str();
+    lt_log_print_dump(torrent::LOG_CRITICAL, dump.c_str(), dump.size(), "Caught signal: '%s'.", signal_reason);
+  }
 
   torrent::log_cleanup();
   std::abort();
@@ -961,9 +956,9 @@ do_panic(int signum) {
   SignalHandler::set_default(signum);
   display::Canvas::cleanup();
 
-  // Use printf here instead...
+  std::stringstream output;
 
-  std::cout << "Caught " << SignalHandler::as_string(signum) << ", dumping stack:" << std::endl;
+  output << "Caught " << SignalHandler::as_string(signum) << ", dumping stack:" << std::endl;
   
 #ifdef USE_EXECINFO
   void* stackPtrs[20];
@@ -973,27 +968,21 @@ do_panic(int signum) {
   char** stackStrings = backtrace_symbols(stackPtrs, stackSize);
 
   for (int i = 0; i < stackSize; ++i)
-    std::cout << i << ' ' << stackStrings[i] << std::endl;
+    output << stackStrings[i] << std::endl;
 
 #else
-  std::cout << "Stack dump not enabled." << std::endl;
+  output << "Stack dump not enabled." << std::endl;
 #endif
   
-  // Dumping virtual memory map information to file:
-  // char dump_path[256];
-  // snprintf(dump_path, 256, "./rtorrent.map.%u", getpid());
-
-  // int dump_fd = open(dump_path, O_RDWR | O_CREAT);
-
-  // if (dump_fd == -1) {
-  //   printf("Could not create vmmap dump file '%s'.", dump_path);
-  //   goto do_panic_exit;
-  // }
-
-// do_panic_exit:
-
   if (signum == SIGBUS)
-    std::cout << "A bus error probably means you ran out of diskspace." << std::endl;
+    output << "A bus error probably means you ran out of diskspace." << std::endl;
+
+  std::cout << output.rdbuf();
+
+  if (lt_log_is_valid(torrent::LOG_CRITICAL)) {
+    std::string dump = output.str();
+    lt_log_print_dump(torrent::LOG_CRITICAL, dump.c_str(), dump.size(), "Caught signal: '%s.", strsignal(signum));
+  }
 
   torrent::log_cleanup();
   std::abort();
@@ -1038,7 +1027,7 @@ print_help() {
   std::cout << "  o                 View trackers" << std::endl;
   std::cout << std::endl;
 
-  std::cout << "Report bugs to <jaris@ifi.uio.no>." << std::endl;
+  std::cout << "Report bugs to <sundell.software@gmail.com>." << std::endl;
 
   exit(0);
 }
